Installation — linkml documentation

# Installation

The installation for requires Python 3.6 or greater.

## Installation for users

First clone the GitHub repository and then install,

    git clone https://github.com/linkml/linkml
    cd linkml
    python setup.py install

## Installation for developers

To build directly from source, first clone the GitHub repository,

    git clone https://github.com/linkml/linkml
    cd linkml

Then install the necessary dependencies listed in `requirements.txt`.

    pip3 install -r requirements.txt

For convenience, make use of the `venv` module in Python 3 to create a lightweight virtual environment:

    . environment.sh

    pip install -r requirements.txt